import shutil
import os

import robosignatory.utils as utils

import logging
log = logging.getLogger("robosignatory.work")


def process_atomic(sigul_helper, ref, commitid, key, directory, ref_to):
    refpath = os.path.join(directory, 'refs', 'heads', ref)
    if not os.path.exists(refpath):
        log.info('Ref file at %s not found. Skipping' % refpath)
        return

    # This check is just to make sure this isn't a delayed message. This
    # same check is performed by sigul itself, but let's abort early and
    # clearly
    with open(refpath, 'r') as f:
        cur_commitid = f.read().replace('\n', '')
        if cur_commitid != commitid:
            log.info('Current commitid NOT matching: %s != %s. Skipping' %
                     (cur_commitid, commitid))
            return

    commitpath = os.path.join(directory, 'objects', commitid[:2],
                              commitid[2:] + '.commit')
    commitmetapath = commitpath + 'meta'

    if not os.path.exists(commitpath):
        log.info('Commit file at %s not found. Skipping' % commitpath)
        return
    if os.path.exists(commitmetapath):
        log.info('Commitmeta file at %s found. Skipping' % commitmetapath)
        return

    log.info('All checks passed, signing %s with %s' % (commitid, key))
    cmdline = sigul_helper.build_atomic_cmdline(key,
                                                commitid,
                                                commitpath,
                                                commitmetapath)
    log.info('Signing command line: %s' % cmdline)

    ret, stdout, stderr = utils.run_command(cmdline)
    if ret != 0:
        log.error('Error signing! Signing output: %s, stdout: %s, '
                  'stderr: %s', ret, stdout, stderr)
        return

    log.info('Commit was succesfully signed, moving to %s' % ref_to)
    if ref == ref_to:
        log.info('Non-gated, not moving')
    else:
        newrefpath = os.path.join(directory, 'refs', 'heads', ref_to)
        if os.path.exists(newrefpath):
            with open(newrefpath, 'r') as f:
                log.info('Previous commit for %s: %s'
                         % (ref_to, f.read().replace('\n', '')))
        else:
            log.info('New ref did not exist')
        log.info('Copying %s -> %s' % (refpath, newrefpath))
        shutil.copyfile(refpath, newrefpath)
        log.info('Ref copied')

    log.info('Done')
